From mboxrd@z Thu Jan 1 00:00:00 1970 Return-Path: Received: (majordomo@vger.kernel.org) by vger.kernel.org via listexpand id S1753757Ab1I0XHp (ORCPT ); Tue, 27 Sep 2011 19:07:45 -0400 Received: from e37.co.us.ibm.com ([32.97.110.158]:32889 "EHLO e37.co.us.ibm.com" rhost-flags-OK-OK-OK-OK) by vger.kernel.org with ESMTP id S1752693Ab1I0XHn (ORCPT ); Tue, 27 Sep 2011 19:07:43 -0400 Date: Tue, 27 Sep 2011 16:07:37 -0700 From: "Darrick J. Wong" To: Andreas Dilger , Herbert Xu , Theodore Tso , David Miller Cc: Bob Pearson , linux-kernel , Mingming Cao , linux-crypto , linux-fsdevel , linux-ext4@vger.kernel.org Subject: Re: [PATCH v2 0/3] crc32c: Add faster algorithm and self-test code Message-ID: <20110927230737.GP12086@tux1.beaverton.ibm.com> Reply-To: djwong@us.ibm.com References: <20110927221239.21653.17489.stgit@elm3c44.beaverton.ibm.com> MIME-Version: 1.0 Content-Type: text/plain; charset=us-ascii Content-Disposition: inline In-Reply-To: <20110927221239.21653.17489.stgit@elm3c44.beaverton.ibm.com> User-Agent: Mutt/1.5.17+20080114 (2008-01-14) Sender: linux-kernel-owner@vger.kernel.org List-ID: X-Mailing-List: linux-kernel@vger.kernel.org On Tue, Sep 27, 2011 at 03:12:39PM -0700, Darrick J. Wong wrote: > Hi all, > > This patchset replaces the current crc32c software implementation, which uses a > slow per-byte lookup table algorithm, with a faster implementation that uses an > adaptation of the slice-by-8 algorithm that Bob Pearson has been pushing for > crc32. > > The motivation for this patchset is that I am working on adding full metadata > checksumming to ext4[1]. As far as performance impact of adding checksumming > goes, I see nearly no change with a standard mail server ffsb simulation. On a > test that involves only file creation and deletion and extent tree writes, I > see a drop of about 50 pcercent with the current kernel crc32c implementation; > this improves to a drop of about 20 percent with the enclosed crc32c code. > > When metadata is usually a small fraction of total IO, this new implementation > doesn't help much because metadata is usually a small fraction of total IO. > However, when we are doing IO that is almost all metadata (such as rm -rf'ing a > tree), then this patch speeds up the operation substantially. > > Please have a look at the patches, and please feel free to suggest any changes. > I will be at LPC next week if anyone wishes to discuss, debate, or protest. Oops, ignore that sentence, since LPC has long passed. :( --D > > Incidentally, given that iscsi, sctp, and btrfs also use crc32c, this patchset > should improve their speed as well. I have not yet quantified that, however. > > v2: Use the crypto test manager code to check crc32c operation. > > --D > > [1] https://ext4.wiki.kernel.org/index.php/Ext4_Metadata_Checksums